@@ -102,13 +102,13 @@ define ([
             console.log("Entering canonicalizeTimeRange() with argument", tr);
             var ttr = String(tr).trim().replace(/\s/g, ''),
                 ttrs;
-            if (ttr.match(/^\d*:{0,1}\d*-\d*:{0,1}\d*$/)) {
+            if (/^\d*:{0,1}\d*-\d*:{0,1}\d*$/.test(ttr)) {
                 console.log(tr + " is a standard time range");
                 return canonicalizeTimeRangeStandard(ttr);
-            } else if (ttr.match(/^\d+:{0,1}\d*\+\d+:{0,1}\d*/)) {
+            } else if (/^\d+:{0,1}\d*\+\d+:{0,1}\d*/.test(ttr)) {
                 console.log(tr + " is an offset time range");
                 return canonicalizeTimeRangeOffset(ttr);
-            } else if (ttr.match(/^\+\d+:{0,1}\d*/)) {
+            } else if (/^\+\d+:{0,1}\d*/.test(ttr)) {
                 console.log(tr + " is a last-interval-plus-offset time range");
                 ttrs = canonicalizeTime(ttr.replace(/\+/g, ''));
                 if (ttrs === null) {
@@ -179,12 +179,36 @@ define ([
             return ftr;
         },
 
+        intToDay = function (d) {
+            var day = null;
+            // if 0 <= m <= 6, return three-letter string signifying the day
+            // of the week; otherwise, return null
+            console.log("Entering intToDay() with argument", d);
+            d = parseInt(d, 10);
+            if (d === 0) {
+                day = "SUN";
+            } else if (d === 1) {
+                day = "MON";
+            } else if (d === 2) {
+                day = "TUE";
+            } else if (d === 3) {
+                day = "WED";
+            } else if (d === 4) {
+                day = "THU";
+            } else if (d === 5) {
+                day = "FRI";
+            } else if (d === 6) {
+                day = "SAT";
+            }
+            return day;
+        },
+
         intToMonth = function (m) {
+            var month = null;
             // if 1 <= m <= 12, return three-letter string signifying the month
             // otherwise, return null
             console.log("Entering intToMonth() with argument", m);
-            var m = parseInt(m, 10),
-                month = null;
+            m = parseInt(m, 10);
             if (m === 1) {
                 month = "JAN";
             } else if (m === 2) {
@@ -227,6 +251,37 @@ define ([
             return canonicalizeTime(quotient + ":" + remainder);
         },
 
+        monthToInt = function (month) {
+            console.log("Entering monthToInt() with argument", month);
+            var m = 0;
+            if (month === "JAN") {
+                m = 1;
+            } else if (month === "FEB") {
+                m = 2;
+            } else if (month === "MAR") {
+                m = 3;
+            } else if (month === "APR") {
+                m = 4;
+            } else if (month === "MAY") {
+                m = 5;
+            } else if (month === "JUN") {
+                m = 6;
+            } else if (month === "JUL") {
+                m = 7;
+            } else if (month === "AUG") {
+                m = 8;
+            } else if (month === "SEP") {
+                m = 9;
+            } else if (month === "OCT") {
+                m = 10;
+            } else if (month === "NOV") {
+                m = 11;
+            } else if (month === "DEC") {
+                m = 12;
+            }
+            return m;
+        }, // intToMonth
+
         strToMonth = function (buf) {
             console.log("Entering strToMonth() with argument", buf);
             var m = String(buf).toLowerCase().slice(0, 3),
@@ -279,6 +334,19 @@ define ([
             return buf[0] * 60 + buf[1];
         },
 
+        tsrangeToTimeRange = function (tsr) {
+            // tsr looks like this: ["2017-10-20 08:00:00+02","2017-10-20 12:00:00+02")
+            var begin, end, h, m, s, re = /\d{2}:\d{2}:\d{2}/;
+            [begin, end] = tsr.split(',');
+            begin = begin.match(re)[0];
+            [h, m, s] = begin.split(':');
+            begin = h + ':' + m;
+            end = end.match(re)[0];
+            [h, m, s] = end.split(':');
+            end = h + ':' + m;
+            return begin + '-' + end;
+        },
+
         vetDateYYYYMMDD = function (ds) {
             console.log("Entering vetDateYYYYMMDD() with argument", ds);
             var y = parseInt(ds[0], 10),
@@ -387,10 +455,14 @@ define ([
 
         canonicalizeTimeRange: canonicalizeTimeRange,
 
+        intToDay: intToDay,
+
         intToMonth: intToMonth,
 
         minutesToTime: minutesToTime,
 
+        monthToInt: monthToInt,
+
         // convert "YYYY-MM-DD HH:DD:SS+TZ" string into YYYY-MMM-DD
         readableDate: function (urd) {
             var ymd = urd.substr(0, urd.indexOf(" ")).split('-'),
@@ -412,6 +484,8 @@ define ([
 
         timeToMinutes: timeToMinutes,
 
+        tsrangeToTimeRange: tsrangeToTimeRange,
+
         vetDateYYYYMMDD: vetDateYYYYMMDD,
 
         vetDateOffset: vetDateOffset,
