@@ -252,9 +252,9 @@ define ([
         // unwind stack until given target is reached
         // optional object to pass to start()
         unwindToTarget = function (tname, obj) {
+            var i, tgt;
             console.log("Unwinding the stack to target " + tname);
-            var tgt;
-            for (var i = _stack.length; i > 0; i--) {
+            for (i = _stack.length; i > 0; i -= 1) {
                 tgt = _stack[i - 1].target;
                 if (tgt.name === tname) {
                    break;
@@ -266,8 +266,8 @@ define ([
         
         unwindToFlag = function () {
             console.log("Unwinding the stack to flag");
-            var flag;
-            for (var i = _stack.length; i > 0; i--) {
+            var flag, i;
+            for (i = _stack.length; i > 0; i -= 1) {
                 flag = _stack[i - 1].flag;
                 if (flag) {
                    break;
@@ -277,10 +277,23 @@ define ([
             _stack[_stack.length - 1].target.start();
         },
 
+        unwindToType = function (targetType) {
+            var i, tgt;
+            console.log("Unwinding stack to nearest target of type " + targetType);
+            for (i = _stack.length; i > 0; i -= 1) {
+                tgt = _stack[i - 1].target;
+                if (tgt.type === targetType) {
+                   break;
+                }
+                popWithoutStart();
+            }
+            tgt.start();
+        },
+
         // grep stack for a target name (exact match)
         grep = function (tname) {
-            var retval = false;
-            for (var i=0; i<_stack.length; i++) {
+            var i, retval = false;
+            for (i = 0; i < _stack.length; i += 1) {
                 if (_stack[i].target.name === tname) {
                     return true;
                 }
@@ -315,7 +328,8 @@ define ([
         "unsetTarget": unsetTarget,
         "unsetXTarget": unsetXTarget,
         "unwindToFlag": unwindToFlag,
-        "unwindToTarget": unwindToTarget
+        "unwindToTarget": unwindToTarget,
+        "unwindToType": unwindToType,
     };
 
 });
